@@ -1,5 +1,5 @@
 /* GNU Mailutils -- a suite of utilities for electronic mail
-   Copyright (C) 2011-2012, 2014-2018 Free Software Foundation, Inc.
+   Copyright (C) 2011-2019 Free Software Foundation, Inc.
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
@@ -26,7 +26,11 @@ void
 _mu_close_handler (mu_imap_t imap)
 {
   if (imap->response == MU_IMAP_OK)
-    imap->session_state = MU_IMAP_SESSION_AUTH;
+    {
+      imap->session_state = MU_IMAP_SESSION_AUTH;
+      free (imap->mbox_name);
+      imap->mbox_name = NULL;
+    }
 }
 
 int
