@@ -1,6 +1,5 @@
 /* GNU Mailutils -- a suite of utilities for electronic mail
-   Copyright (C) 1999-2001, 2004-2007, 2009-2012, 2014-2016 Free
-   Software Foundation, Inc.
+   Copyright (C) 1999-2019 Free Software Foundation, Inc.
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
@@ -432,7 +431,7 @@ _rcpt_to_addr (mu_smtp_t smtp, mu_address_t addr, size_t *pcount)
       const char *to = NULL;
 
       status = mu_address_sget_email (addr, i, &to);
-      if (status == 0)
+      if (status == 0 && to)
 	{
 	  status = mu_smtp_rcpt_basic (smtp, to, NULL);
 	  if (status == 0)
@@ -474,7 +473,9 @@ smtp_send_message (mu_mailer_t mailer, mu_message_t msg,
   status = mu_address_sget_email (argfrom, 1, &mail_from);
   if (status)
     return status;
-  
+  if (!mail_from)
+    return MU_ERR_NOENT;
+      
   if (mu_smtp_capa_test (smtp, "SIZE", &size_str) == 0 &&
       mu_message_size (msg, &size) == 0 &&
       mu_message_lines (msg, &lines) == 0)
@@ -602,5 +603,4 @@ _mailer_smtp_init (mu_mailer_t mailer)
 #include <stdio.h>
 #include <mailutils/sys/registrar.h>
 mu_record_t     mu_smtp_record = NULL;
-mu_record_t     mu_remote_smtp_record = NULL;
 #endif
