@@ -1,6 +1,5 @@
 /* GNU Mailutils -- a suite of utilities for electronic mail
-   Copyright (C) 1999, 2001-2002, 2005, 2007, 2009-2012, 2014-2015 Free
-   Software Foundation, Inc.
+   Copyright (C) 1999-2019 Free Software Foundation, Inc.
 
    GNU Mailutils is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -83,8 +82,7 @@ reply0 (msgset_t *mspec, mu_message_t msg, void *data)
 	  const char *email;
 	  if (mu_address_sget_email (addr, i, &email) || email == NULL)
 	    continue;
-	  if ((mailvar_get (NULL, "metoo", mailvar_type_boolean, 0) == 0)
-	      || !mail_is_my_name (email))
+	  if (mailvar_is_true ("metoo") || !mail_is_my_name (email))
 	    compose_header_set (&env, MU_HEADER_TO,
 				email,
 				COMPOSE_SINGLE_LINE);
@@ -121,9 +119,7 @@ reply0 (msgset_t *mspec, mu_message_t msg, void *data)
   
   make_in_reply_to (&env, msg);
   make_references (&env, msg);
-  status = mail_send0 (&env,
-		       mailvar_get (NULL, "byname", mailvar_type_boolean, 0)
-		                     == 0);
+  status = mail_send0 (&env, mailvar_is_true ("byname"));
   compose_destroy (&env);
 
   return status;
@@ -133,7 +129,7 @@ int
 mail_reply (int argc, char **argv)
 {
   int lower = mu_islower (argv[0][0]);
-  if (mailvar_get (NULL, "flipr", mailvar_type_boolean, 0) == 0)
+  if (mailvar_is_true ("flipr"))
     lower = !lower;
   return util_foreach_msg (argc, argv, MSG_NODELETED, reply0, &lower);
 }
