@@ -1,6 +1,5 @@
 /* GNU Mailutils -- a suite of utilities for electronic mail
-   Copyright (C) 2002, 2005, 2007, 2009-2012, 2014-2016 Free Software
-   Foundation, Inc.
+   Copyright (C) 2002-2019 Free Software Foundation, Inc.
 
    GNU Mailutils is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -20,9 +19,18 @@
 
 #define MH_GETOPT_DEFAULT_FOLDER 0x1
 
+struct mh_optinit
+{
+  char const *opt;   /* Option name */
+  char const *var;   /* mh_property name */
+};
+
+void mh_getopt_ext (int *pargc, char ***pargv, struct mu_option *options,
+		    int mhflags, struct mh_optinit *optinit,
+		    char *argdoc, char *progdoc, char *extradoc);
+
 void mh_getopt (int *pargc, char ***pargv, struct mu_option *options,
-		int flags,
-		char *argdoc, char *progdoc, char *extradoc);
+		int flags, char *argdoc, char *progdoc, char *extradoc);
 
 void mh_opt_notimpl (struct mu_parseopt *po, struct mu_option *opt,
 		     char const *arg);
@@ -35,6 +43,12 @@ void mh_opt_find_file (struct mu_parseopt *po, struct mu_option *opt,
 		       char const *arg);
 void mh_opt_read_formfile (struct mu_parseopt *po, struct mu_option *opt,
 			   char const *arg);
+
+void mh_opt_parse_formfile (struct mu_parseopt *po, struct mu_option *opt,
+			    char const *arg);
+void mh_opt_parse_format (struct mu_parseopt *po, struct mu_option *opt,
+			  char const *arg);
+
 void mh_opt_set_folder (struct mu_parseopt *po, struct mu_option *opt,
 			char const *arg);
 
